<script>
import AppLayout from "@/Layouts/AppLayout.vue";
import Toast from "@/Componentes/Toastify/Toast.vue";
import {useForm} from "@inertiajs/vue3";
import {MasterMethods} from "@/Store/Functions.js";
import Accordion from "@/Componentes/Accordion.vue";

export default {
    name: "Clouds",
    components: {Accordion, Toast, AppLayout},
    created() {
        this.$page.props.breadcrumbs = ["GDAdictos","Configuración","Unidades Compartidas"];
        if(this.categories?.length < 1 || !this.categories){
            this.$page.props.warning = "No hay categorías disponibles";
        }
    },
    data() {
        return {
            sites: this.$page.props?.sites,
            cloud: useForm({
                site: null,
                category_id: null
            }),
            categories: this.$page.props.categories
        }
    },
    methods: {
       ...MasterMethods,
        submit() {
           this.resetForm(this.cloud);
            this.cloud.post(route('clouds.store'), {
                preserveScroll: true,
                onSuccess: () => {
                    this.cloud.reset();
                    this.$page.props.breadcrumbs = ["GDAdictos","Configuración","Unidades Compartidas"];
                }
            });
        }
    }
}
</script>

<template>
    <AppLayout title="Unidades Compartidas">
        <Toast />
        <div class="container">
            <div class="row justify-content-between">
                <div class="col-sm-12 col-md-5">
                    <div class="card card-info card-outline">
                        <div class="card-header py-1">
                            <h3 class="card-title font-bold text-sm">Configurar unidad compartida</h3>
                        </div>
                        <div class="card-body">
                            <form v-on:submit.prevent="submit">
                                <div class="form-group">
                                    <label for="exampleInputBorder">Sitios:</label>
                                    <select required class="form-control form-control-border" v-model="cloud.site">
                                        <option v-for="site in sites" :value="site">{{ site.displayName.replace("@","") }}</option>
                                    </select>
                                </div>
                                <div class="form-group">
                                    <label for="exampleInputBorder">Categorias:</label>
                                    <select required class="form-control form-control-border" v-model="cloud.category_id">
                                        <option v-for="item in categories" :value="item.id">{{ item.name }}</option>
                                    </select>
                                </div>
                                <div class="text-end">
                                    <button type="button" @click="cloud.reset()" class="btn bg-red-500 hover:bg-red-400 text-white btn-sm me-2">Cancelar</button>
                                    <button class="btn bg-cyan-500 hover:bg-cyan-400 text-white btn-sm">Aceptar</button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
                <div class="col-sm-12 col-md-5">
                    <div id="accordion">
                        <Accordion v-for="item in $page.props?.categories" :header="item.name + ' (' + item?.clouds?.length + ')'">
                            <ul class="list-group list-group-flush">
                                <li v-for="cloud in item?.clouds" class="list-group-item py-1 text-sm">
                                    {{ cloud.displayName }}
                                </li>
                            </ul>
                        </Accordion>
                    </div>
                </div>
            </div>
        </div>
    </AppLayout>
</template>

<style scoped>

</style>
